@@ -25,29 +25,29 @@ func (c *Config) newCompletionCmd() *cobra.Command {
 }
 
 func (c *Config) runCompletionCmd(cmd *cobra.Command, args []string) error {
-	var sb strings.Builder
-	sb.Grow(16384)
+	builder := strings.Builder{}
+	builder.Grow(16384)
 	switch args[0] {
 	case "bash":
 		includeDesc := true
-		if err := cmd.Root().GenBashCompletionV2(&sb, includeDesc); err != nil {
+		if err := cmd.Root().GenBashCompletionV2(&builder, includeDesc); err != nil {
 			return err
 		}
 	case "fish":
 		includeDesc := true
-		if err := cmd.Root().GenFishCompletion(&sb, includeDesc); err != nil {
+		if err := cmd.Root().GenFishCompletion(&builder, includeDesc); err != nil {
 			return err
 		}
 	case "powershell":
-		if err := cmd.Root().GenPowerShellCompletion(&sb); err != nil {
+		if err := cmd.Root().GenPowerShellCompletion(&builder); err != nil {
 			return err
 		}
 	case "zsh":
-		if err := cmd.Root().GenZshCompletion(&sb); err != nil {
+		if err := cmd.Root().GenZshCompletion(&builder); err != nil {
 			return err
 		}
 	default:
 		return fmt.Errorf("%s: unsupported shell", args[0])
 	}
-	return c.writeOutputString(sb.String())
+	return c.writeOutputString(builder.String())
 }
