@@ -27,7 +27,6 @@ import (
 	"github.com/coreos/go-semver/semver"
 	gogit "github.com/go-git/go-git/v5"
 	"github.com/go-git/go-git/v5/plumbing/format/diff"
-	"github.com/google/gops/agent"
 	"github.com/mitchellh/mapstructure"
 	"github.com/rs/zerolog"
 	"github.com/rs/zerolog/log"
@@ -85,7 +84,6 @@ type Config struct {
 	debug            bool
 	dryRun           bool
 	force            bool
-	gops             bool
 	homeDir          string
 	keepGoing        bool
 	noPager          bool
@@ -576,7 +574,6 @@ func (c *Config) close() error {
 		err = multierr.Append(err, err2)
 	}
 	pprof.StopCPUProfile()
-	agent.Close()
 	return err
 }
 
@@ -1194,7 +1191,6 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.BoolVar(&c.debug, "debug", c.debug, "Include debug information in output")
 	persistentFlags.BoolVarP(&c.dryRun, "dry-run", "n", c.dryRun, "Do not make any modifications to the destination directory")
 	persistentFlags.BoolVar(&c.force, "force", c.force, "Make all changes without prompting")
-	persistentFlags.BoolVar(&c.gops, "gops", c.gops, "Enable gops agent")
 	persistentFlags.BoolVarP(&c.keepGoing, "keep-going", "k", c.keepGoing, "Keep going as far as possible after an error")
 	persistentFlags.BoolVar(&c.noPager, "no-pager", c.noPager, "Do not use the pager")
 	persistentFlags.BoolVar(&c.noTTY, "no-tty", c.noTTY, "Do not attempt to get a TTY for reading passwords")
@@ -1208,7 +1204,6 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		rootCmd.MarkPersistentFlagFilename("cpu-profile"),
 		persistentFlags.MarkHidden("cpu-profile"),
 		rootCmd.MarkPersistentFlagDirname("destination"),
-		persistentFlags.MarkHidden("gops"),
 		rootCmd.MarkPersistentFlagFilename("output"),
 		persistentFlags.MarkHidden("safe"),
 		rootCmd.MarkPersistentFlagDirname("source"),
@@ -1377,13 +1372,6 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		}
 	}
 
-	// Enable gops if configured.
-	if c.gops {
-		if err := agent.Listen(agent.Options{}); err != nil {
-			return err
-		}
-	}
-
 	// Read the config file.
 	if err := c.readConfig(); err != nil {
 		if !boolAnnotation(cmd, doesNotRequireValidConfig) {
@@ -1825,6 +1813,11 @@ func (c *Config) useBuiltinAgeAutoFunc() bool {
 
 // useBuiltinGitAutoFunc detects whether the builitin git should be used.
 func (c *Config) useBuiltinGitAutoFunc() bool {
+	// useBuiltinGit is false by default on Solaris as it uses the unavailable
+	// flock function.
+	if runtime.GOOS == "solaris" {
+		return false
+	}
 	if _, err := exec.LookPath(c.Git.Command); err == nil {
 		return false
 	}
