@@ -129,7 +129,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	shell, _ := shell.CurrentUserShell()
-	editCommand, _ := c.editor()
+	editCommand, _ := c.editor(nil)
 	checks := []check{
 		&versionCheck{
 			versionInfo: c.versionInfo,
@@ -275,6 +275,9 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 	fmt.Fprint(resultWriter, "RESULT\tCHECK\tMESSAGE\n")
 	for _, check := range checks {
 		checkResult, message := check.Run(c.baseSystem)
+		if checkResult == checkResultSkipped {
+			continue
+		}
 		// Conceal the user's actual home directory in the message as the
 		// output of chezmoi doctor is often posted publicly and would otherwise
 		// reveal the user's username.
