@@ -27,9 +27,29 @@ import (
 	"github.com/twpayne/chezmoi/v2/internal/cmd"
 )
 
+// FIXME remove the following when
+// https://github.com/rogpeppe/go-internal/pull/147 is merged.
+const (
+	goosList   = "aix android darwin dragonfly freebsd hurd illumos ios js linux nacl netbsd openbsd plan9 solaris windows zos "
+	goarchList = "386 amd64 amd64p32 arm armbe arm64 arm64be loong64 mips mipsle mips64 mips64le mips64p32 mips64p32le ppc ppc64 ppc64le riscv riscv64 s390 s390x sparc sparc64 wasm "
+)
+
+var (
+	KnownOS   = make(map[string]bool)
+	KnownArch = make(map[string]bool)
+)
+
+func init() {
+	for _, v := range strings.Fields(goosList) {
+		KnownOS[v] = true
+	}
+	for _, v := range strings.Fields(goarchList) {
+		KnownArch[v] = true
+	}
+}
+
 var umaskConditionRx = regexp.MustCompile(`\Aumask:([0-7]{3})\z`)
 
-//nolint:interfacer
 func TestMain(m *testing.M) {
 	os.Exit(testscript.RunMain(m, map[string]func() int{
 		"chezmoi": func() int {
@@ -66,17 +86,8 @@ func TestScript(t *testing.T) {
 			"unix2dos":       cmdUNIX2DOS,
 		},
 		Condition: func(cond string) (bool, error) {
-			switch cond {
-			case "darwin":
-				return runtime.GOOS == "darwin", nil
-			case "freebsd":
-				return runtime.GOOS == "freebsd", nil
-			case "linux":
-				return runtime.GOOS == "linux", nil
-			case "openbsd":
-				return runtime.GOOS == "openbsd", nil
-			case "windows":
-				return runtime.GOOS == "windows", nil
+			if result, valid := goosCondition(cond); valid {
+				return result, nil
 			}
 			if m := umaskConditionRx.FindStringSubmatch(cond); m != nil {
 				umask, _ := strconv.ParseInt(m[1], 8, 64)
@@ -523,6 +534,61 @@ func cmdUNIX2DOS(ts *testscript.TestScript, neg bool, args []string) {
 	}
 }
 
+// goosCondition evaluates cond as a logical OR of GOARCHes or GOOSes enclosed
+// in parentheses, returning true if any of them match.
+func goosCondition(cond string) (result, valid bool) {
+	// FIXME remove the following two if statements when
+	// https://github.com/rogpeppe/go-internal/pull/147 is merged, and use
+	// github.com/rogpeppe/go-internal/imports.Known{Arch,OS} instead
+	if _, ok := KnownArch[cond]; ok {
+		result = runtime.GOARCH == cond
+		valid = true
+		return
+	}
+	if _, ok := KnownOS[cond]; ok {
+		result = runtime.GOOS == cond
+		valid = true
+		return
+	}
+
+	// Interpret the condition as a logical OR of terms in parantheses.
+	if !strings.HasPrefix(cond, "(") || !strings.HasSuffix(cond, ")") {
+		result = false
+		valid = false
+		return
+	}
+	cond = strings.TrimPrefix(cond, "(")
+	cond = strings.TrimSuffix(cond, ")")
+	terms := strings.Split(cond, "||")
+
+	// If any of the terms are neither known GOOSes nor GOARCHes then reject the
+	// condition as invalid.
+	for _, term := range terms {
+		if _, ok := KnownOS[term]; !ok {
+			if _, ok := KnownArch[term]; !ok {
+				valid = false
+				return
+			}
+		}
+	}
+
+	// At this point, we know the expression is valid.
+	valid = true
+
+	// If any of the terms match either runtime.GOOS or runtime.GOARCH then
+	// the condition is true.
+	for _, term := range terms {
+		if runtime.GOOS == term || runtime.GOARCH == term {
+			result = true
+			return
+		}
+	}
+
+	// Otherwise, the condtion is false.
+	result = false
+	return
+}
+
 func prependDirToPath(dir, path string) string {
 	return strings.Join(append([]string{dir}, filepath.SplitList(path)...), string(os.PathListSeparator))
 }
@@ -602,7 +668,7 @@ func setup(env *testscript.Env) error {
 				Contents: []byte(chezmoitest.JoinLines(
 					`#!/bin/sh`,
 					``,
-					`echo $PWD >> '`+filepath.Join(env.WorkDir, "shell.log")+`'`,
+					`pwd >> '`+filepath.Join(env.WorkDir, "shell.log")+`'`,
 				)),
 			},
 		}
